# metaschool

--------------------------------------------------------------------------------

[![Build Status](https://travis-ci.com/seba-1511/metaschool.svg?branch=master)](https://travis-ci.com/seba-1511/metaschool)

Template to start new PyPI packages

To get started, grep and replace for `metaschool` everywhere.
